import React from 'react'
import { Link } from '@inertiajs/react'

export default function ImageCard({ image, showActions = true }) {
  const statusColors = {
    pending: 'bg-yellow-100 text-yellow-800',
    approved: 'bg-green-100 text-green-800',
    rejected: 'bg-red-100 text-red-800',
  }

  return (
    <div className="bg-white overflow-hidden shadow rounded-lg">
      <div className="relative pb-[75%]">
        <img
          src={image.file_url}
          alt={image.title}
          className="absolute h-full w-full object-cover"
        />
      </div>
      <div className="px-4 py-4">
        <h3 className="text-lg font-medium text-gray-900 truncate" title={image.title}>
          {image.title}
        </h3>
        <p className="mt-1 text-sm text-gray-500">
          Uploaded by {image.user?.name || 'Unknown'} on{' '}
          {new Date(image.created_at).toLocaleDateString()}
        </p>
        
        {image.status && (
          <span className={`inline-flex mt-2 items-center px-2.5 py-0.5 rounded-full text-xs font-medium ${statusColors[image.status] || 'bg-gray-100 text-gray-800'}`}>
            {image.status.charAt(0).toUpperCase() + image.status.slice(1)}
          </span>
        )}
        
        {image.tags && image.tags.length > 0 && (
          <div className="mt-2 flex flex-wrap gap-1">
            {image.tags.slice(0, 3).map((tag) => (
              <span
                key={tag.id}
                className="inline-flex items-center px-2 py-0.5 rounded text-xs font-medium bg-indigo-100 text-indigo-800"
              >
                {tag.name}
              </span>
            ))}
            {image.tags.length > 3 && (
              <span className="inline-flex items-center px-2 py-0.5 rounded text-xs font-medium bg-gray-100 text-gray-800">
                +{image.tags.length - 3} more
              </span>
            )}
          </div>
        )}
        
        {showActions && (
          <div className="mt-4 flex space-x-2">
            <Link
              href={`/images/${image.id}`}
              className="inline-flex items-center px-2.5 py-1.5 border border-gray-300 shadow-sm text-xs font-medium rounded text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
            >
              View
            </Link>
            <Link
              href={`/images/${image.id}/edit`}
              className="inline-flex items-center px-2.5 py-1.5 border border-gray-300 shadow-sm text-xs font-medium rounded text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
            >
              Edit
            </Link>
          </div>
        )}
      </div>
    </div>
  )
}
