import { useState } from 'react'
import { Head, Link } from '@inertiajs/react'
import Layout from '../../Layout'
import * as Tabs from '@radix-ui/react-tabs'
import * as Form from '@radix-ui/react-form'

export default function AdminImagesIndex({ images, filters, auth }) {
  const [searchParams, setSearchParams] = useState({
    title_cont: filters.title_cont || '',
    user_name_cont: filters.user_name_cont || '',
    status_eq: filters.status_eq || '',
    tags_name_cont: filters.tags_name_cont || '',
    created_at_gteq: filters.created_at_gteq || '',
    created_at_lteq: filters.created_at_lteq || '',
  })

  const handleInputChange = (e) => {
    const { name, value } = e.target
    setSearchParams({ ...searchParams, [name]: value })
  }

  return (
    <Layout user={auth.user}>
      <Head title="Admin - Manage Images" />
      <div className="bg-white shadow overflow-hidden sm:rounded-lg">
        <div className="px-4 py-5 sm:px-6 flex justify-between items-center">
          <div>
            <h1 className="text-2xl font-bold text-gray-900">Manage Images</h1>
            <p className="mt-1 max-w-2xl text-sm text-gray-500">
              Review and manage all user-uploaded images
            </p>
          </div>
        </div>

        <Tabs.Root defaultValue="all" className="px-4 sm:px-6 pb-5">
          <Tabs.List className="flex space-x-4 border-b border-gray-200 mb-4">
            <Tabs.Trigger
              value="all"
              className="px-3 py-2 text-sm font-medium text-gray-500 hover:text-gray-700 hover:border-gray-300 focus:outline-none data-[state=active]:border-b-2 data-[state=active]:border-indigo-500 data-[state=active]:text-indigo-600"
            >
              All Images
            </Tabs.Trigger>
            <Tabs.Trigger
              value="pending"
              className="px-3 py-2 text-sm font-medium text-gray-500 hover:text-gray-700 hover:border-gray-300 focus:outline-none data-[state=active]:border-b-2 data-[state=active]:border-indigo-500 data-[state=active]:text-indigo-600"
            >
              Pending Review
            </Tabs.Trigger>
            <Tabs.Trigger
              value="approved"
              className="px-3 py-2 text-sm font-medium text-gray-500 hover:text-gray-700 hover:border-gray-300 focus:outline-none data-[state=active]:border-b-2 data-[state=active]:border-indigo-500 data-[state=active]:text-indigo-600"
            >
              Approved
            </Tabs.Trigger>
            <Tabs.Trigger
              value="rejected"
              className="px-3 py-2 text-sm font-medium text-gray-500 hover:text-gray-700 hover:border-gray-300 focus:outline-none data-[state=active]:border-b-2 data-[state=active]:border-indigo-500 data-[state=active]:text-indigo-600"
            >
              Rejected
            </Tabs.Trigger>
            <Tabs.Trigger
              value="search"
              className="px-3 py-2 text-sm font-medium text-gray-500 hover:text-gray-700 hover:border-gray-300 focus:outline-none data-[state=active]:border-b-2 data-[state=active]:border-indigo-500 data-[state=active]:text-indigo-600"
            >
              Advanced Search
            </Tabs.Trigger>
          </Tabs.List>

          {['all', 'pending', 'approved', 'rejected'].map((tab) => (
            <Tabs.Content key={tab} value={tab} className="focus:outline-none">
              {images
                .filter(
                  (image) => tab === 'all' || image.status === tab
                )
                .length > 0 ? (
                <div className="overflow-x-auto">
                  <table className="min-w-full divide-y divide-gray-200">
                    <thead className="bg-gray-50">
                      <tr>
                        <th
                          scope="col"
                          className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider"
                        >
                          Image
                        </th>
                        <th
                          scope="col"
                          className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider"
                        >
                          Title
                        </th>
                        <th
                          scope="col"
                          className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider"
                        >
                          Uploader
                        </th>
                        <th
                          scope="col"
                          className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider"
                        >
                          Status
                        </th>
                        <th
                          scope="col"
                          className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider"
                        >
                          Upload Date
                        </th>
                        <th
                          scope="col"
                          className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider"
                        >
                          Actions
                        </th>
                      </tr>
                    </thead>
                    <tbody className="bg-white divide-y divide-gray-200">
                      {images
                        .filter(
                          (image) => tab === 'all' || image.status === tab
                        )
                        .map((image) => (
                          <tr key={image.id}>
                            <td className="px-6 py-4 whitespace-nowrap">
                              <div className="h-16 w-16 relative">
                                <img
                                  src={image.file_url}
                                  alt={image.title}
                                  className="h-16 w-16 object-cover rounded"
                                />
                              </div>
                            </td>
                            <td className="px-6 py-4 whitespace-nowrap">
                              <div className="text-sm font-medium text-gray-900">
                                {image.title}
                              </div>
                              <div className="text-sm text-gray-500 mt-1 flex flex-wrap gap-1">
                                {image.tags.map((tag) => (
                                  <span
                                    key={tag.id}
                                    className="inline-flex items-center px-2 py-0.5 rounded text-xs font-medium bg-indigo-100 text-indigo-800"
                                  >
                                    {tag.name}
                                  </span>
                                ))}
                              </div>
                            </td>
                            <td className="px-6 py-4 whitespace-nowrap">
                              <div className="text-sm text-gray-900">
                                {image.user.name}
                              </div>
                              <div className="text-sm text-gray-500">
                                {image.user.email_address}
                              </div>
                            </td>
                            <td className="px-6 py-4 whitespace-nowrap">
                              <span
                                className={`inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium ${
                                  image.status === 'pending'
                                    ? 'bg-yellow-100 text-yellow-800'
                                    : image.status === 'approved'
                                    ? 'bg-green-100 text-green-800'
                                    : 'bg-red-100 text-red-800'
                                }`}
                              >
                                {image.status}
                              </span>
                            </td>
                            <td className="px-6 py-4 whitespace-nowrap text-sm text-gray-500">
                              {new Date(image.created_at).toLocaleDateString()}
                            </td>
                            <td className="px-6 py-4 whitespace-nowrap text-right text-sm font-medium">
                              <div className="flex space-x-2">
                                <Link
                                  href={`/images/${image.id}`}
                                  className="text-indigo-600 hover:text-indigo-900"
                                >
                                  View
                                </Link>
                                {image.status === 'pending' && (
                                  <>
                                    <Link
                                      href={`/admin/images/${image.id}/approve`}
                                      method="patch"
                                      as="button"
                                      className="text-green-600 hover:text-green-900"
                                    >
                                      Approve
                                    </Link>
                                    <Link
                                      href={`/admin/images/${image.id}/reject`}
                                      method="patch"
                                      as="button"
                                      className="text-red-600 hover:text-red-900"
                                    >
                                      Reject
                                    </Link>
                                  </>
                                )}
                                <Link
                                  href={`/admin/images/${image.id}`}
                                  method="delete"
                                  as="button"
                                  className="text-gray-600 hover:text-gray-900"
                                  onClick={(e) => {
                                    if (!confirm('Are you sure you want to delete this image?')) {
                                      e.preventDefault()
                                    }
                                  }}
                                >
                                  Delete
                                </Link>
                              </div>
                            </td>
                          </tr>
                        ))}
                    </tbody>
                  </table>
                </div>
              ) : (
                <div className="text-center py-12">
                  <svg
                    className="mx-auto h-12 w-12 text-gray-400"
                    fill="none"
                    viewBox="0 0 24 24"
                    stroke="currentColor"
                    aria-hidden="true"
                  >
                    <path
                      strokeLinecap="round"
                      strokeLinejoin="round"
                      strokeWidth={2}
                      d="M4 16l4.586-4.586a2 2 0 012.828 0L16 16m-2-2l1.586-1.586a2 2 0 012.828 0L20 14m-6-6h.01M6 20h12a2 2 0 002-2V6a2 2 0 00-2-2H6a2 2 0 00-2 2v12a2 2 0 002 2z"
                    />
                  </svg>
                  <h3 className="mt-2 text-sm font-medium text-gray-900">
                    No images found
                  </h3>
                  <p className="mt-1 text-sm text-gray-500">
                    {tab === 'pending'
                      ? 'There are no pending images to review.'
                      : tab === 'approved'
                      ? 'There are no approved images.'
                      : tab === 'rejected'
                      ? 'There are no rejected images.'
                      : 'There are no images in the system.'}
                  </p>
                </div>
              )}
            </Tabs.Content>
          ))}

          <Tabs.Content value="search" className="focus:outline-none">
            <Form.Root
              className="space-y-6"
              action="/admin/images"
              method="get"
            >
              <div className="grid grid-cols-1 gap-y-6 gap-x-4 sm:grid-cols-6">
                <div className="sm:col-span-3">
                  <Form.Field name="q[title_cont]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      Title
                    </Form.Label>
                    <Form.Control asChild>
                      <input
                        type="text"
                        name="q[title_cont]"
                        value={searchParams.title_cont}
                        onChange={handleInputChange}
                        className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                        placeholder="Search by title"
                      />
                    </Form.Control>
                  </Form.Field>
                </div>

                <div className="sm:col-span-3">
                  <Form.Field name="q[user_name_cont]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      Uploader
                    </Form.Label>
                    <Form.Control asChild>
                      <input
                        type="text"
                        name="q[user_name_cont]"
                        value={searchParams.user_name_cont}
                        onChange={handleInputChange}
                        className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                        placeholder="Search by uploader name"
                      />
                    </Form.Control>
                  </Form.Field>
                </div>

                <div className="sm:col-span-2">
                  <Form.Field name="q[status_eq]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      Status
                    </Form.Label>
                    <Form.Control asChild>
                      <select
                        name="q[status_eq]"
                        value={searchParams.status_eq}
                        onChange={handleInputChange}
                        className="mt-1 block w-full py-2 px-3 border border-gray-300 bg-white rounded-md shadow-sm focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                      >
                        <option value="">Any status</option>
                        <option value="pending">Pending</option>
                        <option value="approved">Approved</option>
                        <option value="rejected">Rejected</option>
                      </select>
                    </Form.Control>
                  </Form.Field>
                </div>

                <div className="sm:col-span-4">
                  <Form.Field name="q[tags_name_cont]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      Tags
                    </Form.Label>
                    <Form.Control asChild>
                      <input
                        type="text"
                        name="q[tags_name_cont]"
                        value={searchParams.tags_name_cont}
                        onChange={handleInputChange}
                        className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                        placeholder="Search by tag"
                      />
                    </Form.Control>
                  </Form.Field>
                </div>

                <div className="sm:col-span-3">
                  <Form.Field name="q[created_at_gteq]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      From Date
                    </Form.Label>
                    <Form.Control asChild>
                      <input
                        type="date"
                        name="q[created_at_gteq]"
                        value={searchParams.created_at_gteq}
                        onChange={handleInputChange}
                        className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                      />
                    </Form.Control>
                  </Form.Field>
                </div>

                <div className="sm:col-span-3">
                  <Form.Field name="q[created_at_lteq]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      To Date
                    </Form.Label>
                    <Form.Control asChild>
                      <input
                        type="date"
                        name="q[created_at_lteq]"
                        value={searchParams.created_at_lteq}
                        onChange={handleInputChange}
                        className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                      />
                    </Form.Control>
                  </Form.Field>
                </div>
              </div>

              <div className="flex justify-end">
                <button
                  type="submit"
                  className="inline-flex justify-center py-2 px-4 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                >
                  Search
                </button>
              </div>
            </Form.Root>
          </Tabs.Content>
        </Tabs.Root>
      </div>
    </Layout>
  )
}
