import { useState } from 'react'
import { Head, Link, useForm } from '@inertiajs/react'
import * as Form from '@radix-ui/react-form'

export default function Register({ errors = {} }) {
  const { data, setData, post, processing } = useForm({
    name: '',
    email_address: '',
    password: '',
    password_confirmation: '',
  })

  const handleSubmit = (e) => {
    e.preventDefault()
    post('/register')
  }

  return (
    <div className="min-h-screen flex flex-col justify-center py-12 sm:px-6 lg:px-8 bg-gray-50">
      <Head title="Register" />
      <div className="sm:mx-auto sm:w-full sm:max-w-md">
        <h2 className="mt-6 text-center text-3xl font-extrabold text-gray-900">
          Create a new account
        </h2>
        <p className="mt-2 text-center text-sm text-gray-600">
          Or{' '}
          <Link
            href="/login"
            className="font-medium text-indigo-600 hover:text-indigo-500"
          >
            log in to your existing account
          </Link>
        </p>
      </div>

      <div className="mt-8 sm:mx-auto sm:w-full sm:max-w-md">
        <div className="bg-white py-8 px-4 shadow sm:rounded-lg sm:px-10">
          <Form.Root className="space-y-6" onSubmit={handleSubmit}>
            <Form.Field name="name" className="space-y-1">
              <Form.Label className="block text-sm font-medium text-gray-700">
                Name
              </Form.Label>
              <Form.Control asChild>
                <input
                  id="name"
                  name="name"
                  type="text"
                  autoComplete="name"
                  required
                  value={data.name}
                  onChange={(e) => setData('name', e.target.value)}
                  className="appearance-none block w-full px-3 py-2 border border-gray-300 rounded-md shadow-sm placeholder-gray-400 focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                />
              </Form.Control>
              {errors.name && (
                <Form.Message className="text-sm text-red-600">
                  {errors.name}
                </Form.Message>
              )}
            </Form.Field>

            <Form.Field name="email_address" className="space-y-1">
              <Form.Label className="block text-sm font-medium text-gray-700">
                Email address
              </Form.Label>
              <Form.Control asChild>
                <input
                  id="email_address"
                  name="email_address"
                  type="email"
                  autoComplete="email"
                  required
                  value={data.email_address}
                  onChange={(e) => setData('email_address', e.target.value)}
                  className="appearance-none block w-full px-3 py-2 border border-gray-300 rounded-md shadow-sm placeholder-gray-400 focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                />
              </Form.Control>
              {errors.email_address && (
                <Form.Message className="text-sm text-red-600">
                  {errors.email_address}
                </Form.Message>
              )}
            </Form.Field>

            <Form.Field name="password" className="space-y-1">
              <Form.Label className="block text-sm font-medium text-gray-700">
                Password
              </Form.Label>
              <Form.Control asChild>
                <input
                  id="password"
                  name="password"
                  type="password"
                  autoComplete="new-password"
                  required
                  value={data.password}
                  onChange={(e) => setData('password', e.target.value)}
                  className="appearance-none block w-full px-3 py-2 border border-gray-300 rounded-md shadow-sm placeholder-gray-400 focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                />
              </Form.Control>
              {errors.password && (
                <Form.Message className="text-sm text-red-600">
                  {errors.password}
                </Form.Message>
              )}
            </Form.Field>

            <Form.Field name="password_confirmation" className="space-y-1">
              <Form.Label className="block text-sm font-medium text-gray-700">
                Confirm Password
              </Form.Label>
              <Form.Control asChild>
                <input
                  id="password_confirmation"
                  name="password_confirmation"
                  type="password"
                  autoComplete="new-password"
                  required
                  value={data.password_confirmation}
                  onChange={(e) => setData('password_confirmation', e.target.value)}
                  className="appearance-none block w-full px-3 py-2 border border-gray-300 rounded-md shadow-sm placeholder-gray-400 focus:outline-none focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                />
              </Form.Control>
            </Form.Field>

            <div>
              <Form.Submit asChild>
                <button
                  type="submit"
                  disabled={processing}
                  className="w-full flex justify-center py-2 px-4 border border-transparent rounded-md shadow-sm text-sm font-medium text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 disabled:opacity-50"
                >
                  {processing ? 'Creating account...' : 'Create account'}
                </button>
              </Form.Submit>
            </div>
          </Form.Root>
        </div>
      </div>
    </div>
  )
}
