import { useState } from 'react'
import { Head, useForm } from '@inertiajs/react'
import Layout from '../Layout'
import * as Form from '@radix-ui/react-form'

export default function Edit({ image, tags, auth, errors = {} }) {
  const { data, setData, patch, processing } = useForm({
    title: image.title || '',
    tags: tags || '',
  })

  const handleSubmit = (e) => {
    e.preventDefault()
    patch(`/images/${image.id}`)
  }

  return (
    <Layout user={auth.user}>
      <Head title={`Edit ${image.title}`} />
      <div className="bg-white shadow overflow-hidden sm:rounded-lg">
        <div className="px-4 py-5 sm:px-6">
          <h1 className="text-2xl font-bold text-gray-900">Edit Image</h1>
          <p className="mt-1 max-w-2xl text-sm text-gray-500">
            Update image details
          </p>
        </div>
        <div className="border-t border-gray-200 px-4 py-5 sm:px-6">
          <div className="mb-6">
            <img
              src={image.file_url}
              alt={image.title}
              className="max-h-64 mx-auto object-contain"
            />
          </div>
          
          <Form.Root className="space-y-6" onSubmit={handleSubmit}>
            <Form.Field name="title" className="space-y-2">
              <Form.Label className="block text-sm font-medium text-gray-700">
                Title
              </Form.Label>
              <Form.Control asChild>
                <input
                  type="text"
                  name="title"
                  value={data.title}
                  onChange={(e) => setData('title', e.target.value)}
                  className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                  placeholder="Enter image title"
                />
              </Form.Control>
              {errors.title && (
                <Form.Message className="text-sm text-red-600">
                  {errors.title}
                </Form.Message>
              )}
            </Form.Field>

            <Form.Field name="tags" className="space-y-2">
              <Form.Label className="block text-sm font-medium text-gray-700">
                Tags
              </Form.Label>
              <Form.Control asChild>
                <input
                  type="text"
                  name="tags"
                  value={data.tags}
                  onChange={(e) => setData('tags', e.target.value)}
                  className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                  placeholder="Enter tags separated by commas (e.g. nature, landscape, mountains)"
                />
              </Form.Control>
              <p className="text-xs text-gray-500">
                Enter tags separated by commas
              </p>
            </Form.Field>

            <div className="flex justify-end space-x-3">
              <a
                href={`/images/${image.id}`}
                className="inline-flex justify-center py-2 px-4 border border-gray-300 shadow-sm text-sm font-medium rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
              >
                Cancel
              </a>
              <Form.Submit asChild>
                <button
                  type="submit"
                  disabled={processing}
                  className="inline-flex justify-center py-2 px-4 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 disabled:opacity-50"
                >
                  {processing ? 'Saving...' : 'Save Changes'}
                </button>
              </Form.Submit>
            </div>
          </Form.Root>
        </div>
      </div>
    </Layout>
  )
}
